# setup.py
from setuptools import setup,find_packages
setup(name = 'vistorch',
      version = '0.0.1.dev1',
      description = 'use visdom on pytorch',
      author = 'xi wei',
      author_email = 'xiwei.cv@gmail.com',
      license = 'BSD',
      keywords = 'visdom torch',
      packages = ['vistorch']
      )
